[anaconda:master 2/3] Quit if no device type name selected.

mulhern amulhern at redhat.com
Thu Oct 16 15:57:53 UTC 2014


Belongs with commit acfd5b4195d9e0a3f4e287757712c9d5bf26afa6.

Signed-off-by: mulhern <amulhern at redhat.com>
---
 pyanaconda/ui/gui/spokes/custom.py | 7 ++++++-
 1 file changed, 6 insertions(+), 1 deletion(-)

diff --git a/pyanaconda/ui/gui/spokes/custom.py b/pyanaconda/ui/gui/spokes/custom.py
index 422a9f4..26a4915 100644
--- a/pyanaconda/ui/gui/spokes/custom.py
+++ b/pyanaconda/ui/gui/spokes/custom.py
@@ -2525,9 +2525,14 @@ class CustomPartitioningSpoke(NormalSpoke, StorageChecker):
         new_type = self._get_current_device_type_name()
         log.debug("device_type_changed: %s", new_type)
 
-        # But the numeric id of the device is what is needed by blivet
+        # Quit if no device type is selected.
+        if new_type is None:
+            return
+
+        # The numeric id of the device is what is needed by blivet.
         new_type = dev_type_from_const(new_type)
 
+        # Quit if device type name is unrecognized by blivet.
         if new_type is None:
             return
 
-- 
1.9.3



More information about the anaconda-patches mailing list